@@ -74,4 +74,28 @@ function hideArray(i){
             node.style.display = display;
         }
     }
-}
\ No newline at end of file
+}
+
+function trOver(id){
+     var node =document.getElementById('tr'+id);
+     var node2 =document.getElementById('tree'+id);
+     if(m_bOver){
+          if(node)
+          node.className = 'trOver';
+          if(node2)
+          node2.className = 'trOver';
+     }
+}
+function trUnder(id){
+     var node =document.getElementById('tr'+id);
+     var node2 =document.getElementById('tree'+id);
+     if(m_bOver){
+          if(node)
+          node.className = '';
+          if(node2)
+          node2.className = '';
+     }
+}
+
+
+
